@@ -116,6 +116,8 @@ void add_target(const xmlDocPtr doc, const xmlChar* target_id);
 void rem_targets(xmlDocPtr doc);
 xmlXPathObjectPtr get_nodeset(const xmlDocPtr doc, const xmlChar* xpath);
 
+void free_curent_func(curent_func *fnc);
+curent_func *create_curent_func();
 
 
 #endif /* _DB_H_ */
