@@ -104,6 +104,7 @@ xmlDocPtr DB_SEND_REQUEST(xmlDocPtr ui_request)
     g_free(g_conf_path);
 
 	db_settings = xmlParseDoc(BAD_CAST xml_conf);
+	xmlFree(xml_conf);
 	node_settings_root = xmlDocGetRootElement(db_settings);
 
     /** if drivers list is null then ERROR! **/
@@ -124,10 +125,13 @@ xmlDocPtr DB_SEND_REQUEST(xmlDocPtr ui_request)
 										node_settings = node_settings->next) {
 
 		/** if driver on and conf, add new target id **/
-		if ( (atoi((char*)xmlGetProp(node_settings,BAD_CAST STATUS_PROP)) == 1) ) {
-			
-			add_target(db_request, xmlNodeGetContent(node_settings));
+		xmlChar* prop_val = xmlGetProp(node_settings,BAD_CAST STATUS_PROP);
+		if ( (atoi((char*)prop_val) == 1) ) {			
+		    xmlChar *target_id = xmlNodeGetContent(node_settings);
+			add_target(db_request, target_id);
+			xmlFree(target_id);
 		}
+		xmlFree(prop_val);
 
 	}	
 
@@ -143,6 +147,7 @@ xmlDocPtr DB_SEND_REQUEST(xmlDocPtr ui_request)
 //    xmlDocDump(stdout, db_settings);
 
     xmlXPathFreeObject(Obj);
+    xmlFreeDoc(db_settings);
     //xmlFreeDoc(ui_request);
 	return db_request;
 }
@@ -217,10 +222,12 @@ xmlDocPtr DB_SAVE_PROFILE(xmlDocPtr drv_response) {
 		add_target(db_resp, (xmlChar*)UI_ID);
 
 	}
+
     xmlXPathFreeObject(Obj);
     xmlFreeDoc(drv_response);
-	return db_resp;
-	
+    g_free(resp_class);
+
+    return db_resp;
 }
 
 /**
@@ -239,7 +246,9 @@ xmlDocPtr DB_GET_PROFILE(xmlDocPtr request)
 
 	/** get profile id **/
 	//gchar* class_name;
-	gchar* func_name;
+	gchar* func_name = NULL;
+    gchar* text_error = NULL;
+    gchar* code_error = NULL;
 
 	/** get profile id **/
 	char* id = db_get_request_id(CLASS_PROFILE, TYPE_REQUEST, request);
@@ -247,11 +256,15 @@ xmlDocPtr DB_GET_PROFILE(xmlDocPtr request)
 	if (id == NULL) {
 		response_list = db_get_owner_metacontact("0");
 		func_name = GET_PROFILE;
+        text_error = DB_GET_ERROR_PROFILE_TEXT;
+        code_error = DB_GET_ERROR_PROFILE_CODE;
 	} else {
 		response_list = db_get_profile(id);	
-		
+        text_error = DB_SAVE_ERROR_FRIENDS_PROFILE_TEXT;
+        code_error = DB_SAVE_ERROR_FRIENDS_PROFILE_CODE;		
 		func_name = GET_FRIENDS_PROFILE;	
 	}	
+	g_free(id);
 
 	if (response_list != NULL) {	
 		xmlNodePtr node_resp = xmlDocGetRootElement((xmlDocPtr)response_list->data);
@@ -261,9 +274,9 @@ xmlDocPtr DB_GET_PROFILE(xmlDocPtr request)
 	
 	} else {
 		db_resp = xmlParseDoc(BAD_CAST db_message); 
-		db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
-					      DB_GET_ERROR_PROFILE_TEXT, 
-					      DB_GET_ERROR_PROFILE_CODE);
+		db_resp = db_generate_message(db_resp,ERROR_MESSAGE, 
+					                          text_error, 
+					                          code_error);
 	}
 	
 
@@ -337,9 +350,9 @@ xmlDocPtr DB_SAVE_FRIENDS(xmlDocPtr drv_response)
     g_free(friends_id);
     g_free(resp_xpath);
 
-	g_debug("DB_SAVE_FRIENDS: END");
+    g_debug("DB_SAVE_FRIENDS: END");
 
-	return db_resp;
+    return db_resp;
 }
 
 
@@ -352,11 +365,11 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
 {
 	g_debug("db_get_friends: START");
 
-	xmlDocPtr struct_response = xmlParseDoc(BAD_CAST db_response);	
+	xmlDocPtr struct_response = xmlParseDoc(BAD_CAST db_response);
 	xmlDocPtr db_resp;
-	GSList* response_list;
+	GSList* response_list = NULL;
 
-	response_list = get_contacts(FALSE);	
+	response_list = get_contacts(FALSE);
 
         if (response_list != NULL) {
 
@@ -367,15 +380,17 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
             gint fr_to = 0;
             xmlChar* str = NULL;
 
-            xmlNodePtr node_set;
+            xmlNodePtr node_set = NULL;
             xmlDocPtr fr_resp = xmlParseDoc(BAD_CAST "<Params><array name=\"contacts\"/></Params>");
             xmlNodePtr fr_resp_root = xmlDocGetRootElement(fr_resp);
 
             xmlNodePtr fr_resp_node = fr_resp_root->children;
 
             guint fr_count = g_slist_length(response_list);
-
-            xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", BAD_CAST g_strdup_printf("%d", fr_count));
+            gchar* fr_count_text = g_strdup_printf("%d", fr_count);
+            
+            xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", BAD_CAST fr_count_text);
+            g_free(fr_count_text);
 
             /** get parametrs in Params node**/
             xmlXPathObject* Obj = db_xpath(REQUEST_PARAMS_TAG_XPATH, request);
@@ -389,6 +404,7 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
                     } else {
                             fr_from = 0;
                     }
+                	xmlFree(str);
 
                     /** get TO **/
                     str = xmlGetProp(node_set,BAD_CAST "To");
@@ -426,12 +442,14 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
                             response_list = NULL;
 
                             while (list_element != NULL) {
-
-                                    if (db_friends_find( (gpointer)list_element->data, (gpointer)str ) == 0) {
-                                            response_list = g_slist_append(response_list, list_element->data);
+				    xmlDocPtr cur_data = (xmlDocPtr)list_element->data;
+                                    list_element = g_slist_remove(list_element, cur_data);
+                                    if (db_friends_find(cur_data, (gpointer)str) == 0) {
+                                            response_list = g_slist_append(response_list, cur_data);
                                             fr_to++;
+                                    }else{
+                                	xmlFreeDoc(cur_data);
                                     }
-                                    list_element = list_element->next;
                             }
 
                             xmlSetProp(fr_resp_node, BAD_CAST "friendsQuantity", BAD_CAST g_strdup_printf("%d", fr_to - 1));
@@ -452,20 +470,27 @@ xmlDocPtr DB_GET_FRIENDS(xmlDocPtr request)
 
         GSList* list = g_slist_nth(response_list, fr_from);
 
-        for (i=fr_from; i<fr_to; i++) {
-
+        for (i=fr_from; i<fr_to && list != NULL; i++) {
             node_set = xmlDocGetRootElement((xmlDocPtr)list->data);
-            xmlUnlinkNode(node_set);
-            xmlAddChild(fr_resp_node, node_set);
+            //xmlUnlinkNode(node_set);
+            xmlAddChild(fr_resp_node, xmlCopyNode(node_set, 1));
+            //xmlAddChild(fr_resp_node, xmlCopyDoc((xmlDocPtr)list->data, 1));
 
             if (list->next == NULL) {
                     break;
             }
 
-            xmlDocSetRootElement((xmlDocPtr)list->data, NULL);
-            xmlFreeDoc((xmlDocPtr)list->data);
+            //xmlDocSetRootElement((xmlDocPtr)list->data, NULL);
             list = list->next;
         }
+        
+        /* clean memory */
+        while(response_list != NULL)
+        {
+    	    xmlDocPtr cur_node = (xmlDocPtr)response_list->data;
+    	    response_list = g_slist_remove(response_list, cur_node);
+    	    xmlFreeDoc(cur_node);
+        }
 
         db_resp = db_generate_response(struct_response, fr_resp_root,
                                                                    CLASS_FRIENDS, GET_FRIENDS);
@@ -554,28 +579,38 @@ xmlDocPtr DB_SAVE_INBOX_MESSAGES(xmlDocPtr drv_response)
     gint (*save_func) (xmlDocPtr, gchar*) = NULL;    
     gchar* text_ok = NULL;
     gchar* code_ok = NULL;
+    gchar* text_error = NULL;
+    gchar* code_error = NULL;
 
     /** get function **/
 	xmlXPathObject *Obj = db_xpath(RESPONSE_TAG_XPATH, drv_response);
     if (Obj->nodesetval->nodeNr != 0 ) {
         xmlNodePtr func_node = Obj->nodesetval->nodeTab[0];
         
-        if (strcmp((char*)xmlGetProp(func_node, BAD_CAST "function"), UPDATE_INBOX_MESSAGES) == 0){
+        xmlChar* func = xmlGetProp(func_node, BAD_CAST "function");
+        if (strcmp((char*)func, UPDATE_INBOX_MESSAGES) == 0){
                 save_func = create_or_update_message; 
                 text_ok = DB_UPDATE_MESSAGE_INBOX_MESSAGES_TEXT;
                 code_ok = DB_UPDATE_MESSAGE_INBOX_MESSAGES_CODE;
+                text_error = DB_GET_ERROR_INBOX_MESSAGES_TEXT;
+                code_error = DB_GET_ERROR_INBOX_MESSAGES_CODE;
         }
 
-        if (strcmp((char*)xmlGetProp(func_node,BAD_CAST "function"), UPDATE_OUTBOX_MESSAGES) == 0){
+        if (strcmp((char*)func, UPDATE_OUTBOX_MESSAGES) == 0){
                 save_func = create_or_update_owner_message; 
                 text_ok = DB_UPDATE_MESSAGE_OUTBOX_MESSAGES_TEXT;
                 code_ok = DB_UPDATE_MESSAGE_OUTBOX_MESSAGES_CODE;
+                text_error = DB_GET_ERROR_OUTBOX_MESSAGES_TEXT;
+                code_error = DB_GET_ERROR_OUTBOX_MESSAGES_CODE;
         }    
+        xmlFree(func);
     
     }
+    xmlXPathFreeObject(Obj);
 
 	gchar* xpath_req = g_strconcat(RESPONSE_PARAMS_TAG_XPATH, "/array/struct", NULL);
 	Obj = db_xpath(xpath_req, drv_response);
+	g_free(xpath_req);
 
 	xmlNodePtr node;
 	xmlDocPtr db_resp;
@@ -590,8 +625,10 @@ xmlDocPtr DB_SAVE_INBOX_MESSAGES(xmlDocPtr drv_response)
 		g_debug("db generate message start");
 		db_resp = xmlParseDoc(BAD_CAST db_message); 
 		db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
-                                              DB_GET_ERROR_INBOX_MESSAGES_TEXT, 
-                                              DB_GET_ERROR_INBOX_MESSAGES_CODE);
+                                               text_error, 
+                                               code_error);
+        xmlFreeDoc(drv_response);
+        xmlXPathFreeObject(Obj);
 		return db_resp;
 	}
 
@@ -610,15 +647,17 @@ xmlDocPtr DB_SAVE_INBOX_MESSAGES(xmlDocPtr drv_response)
 		{
 			db_resp = xmlParseDoc(BAD_CAST db_message); 
 			db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
-                                                      DB_GET_ERROR_INBOX_MESSAGES_TEXT, 
-                                                      DB_GET_ERROR_INBOX_MESSAGES_CODE);
-
+                                                   text_error, 
+                                                   code_error);
+            xmlFreeDoc(drv_response);
+            xmlXPathFreeObject(Obj);
 			return db_resp;		
 		}
-	}
-
-
-	db_resp = xmlParseDoc(BAD_CAST db_message); 
+		g_free(message_id);
+	}   
+    xmlFreeDoc(db_resp);
+	
+    db_resp = xmlParseDoc(BAD_CAST db_message); 
 	db_resp = db_generate_message(db_resp, INFO_MESSAGE, text_ok, code_ok);
     
     xmlFreeDoc(drv_response);
@@ -644,32 +683,46 @@ xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
     xmlDocPtr db_resp;
     gint i;	
 
+    gchar* text_error = NULL;
+    gchar* code_error = NULL;
+    gchar* cur_function = NULL;
 
     xmlXPathObject *Obj = db_xpath(REQUEST_TAG_XPATH, ui_request);
     if (Obj->nodesetval->nodeNr != 0 ) {
         xmlNodePtr func_node = Obj->nodesetval->nodeTab[0];
         
-        if (strcmp((char*)xmlGetProp(func_node,BAD_CAST "function"), GET_INBOX_MESSAGES) == 0){
-                response_list = get_messages();
-                
+        xmlChar* func_name = xmlGetProp(func_node,BAD_CAST "function");
+        if (strcmp((char*)func_name, GET_INBOX_MESSAGES) == 0){
+            response_list = get_messages();
+            text_error = DB_GET_ERROR_INBOX_MESSAGES_TEXT;
+            code_error = DB_GET_ERROR_INBOX_MESSAGES_CODE;
+            cur_function = GET_INBOX_MESSAGES;    
         }
 
-        if (strcmp((char*)xmlGetProp(func_node,BAD_CAST "function"), GET_OUTBOX_MESSAGES) == 0){
-                response_list = get_owner_messages();        
+        if (strcmp((char*)func_name, GET_OUTBOX_MESSAGES) == 0){
+            response_list = get_owner_messages(); 
+            text_error = DB_GET_ERROR_OUTBOX_MESSAGES_TEXT;
+            code_error = DB_GET_ERROR_OUTBOX_MESSAGES_CODE;      
+            cur_function = GET_OUTBOX_MESSAGES;        
         }    
+        xmlFree(func_name);        
     
     }
+    xmlXPathFreeObject(Obj);
     
-    guint messages_count = g_slist_length(response_list);		
-    xmlSetProp(node_root, BAD_CAST "messagesQuantity", BAD_CAST g_strdup_printf("%d", messages_count));
+    guint messages_count = g_slist_length(response_list);
+    gchar* text_count = g_strdup_printf("%d", messages_count);		
+    xmlSetProp(node_root, BAD_CAST "messagesQuantity", BAD_CAST text_count);
+    g_free(text_count);
     
     /** error **/
     if (response_list == NULL ) {
 
- 	db_resp = xmlParseDoc(BAD_CAST db_message); 
-	db_resp = db_generate_message(db_resp, ERROR_MESSAGE, DB_GET_ERROR_INBOX_MESSAGE_TEXT,
-			                                      DB_GET_ERROR_INBOX_MESSAGE_CODE);
-		return db_resp;		
+        db_resp = xmlParseDoc(BAD_CAST db_message); 
+        db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
+                                               text_error,
+		                                       code_error);
+        return db_resp;
    }
    response_list = g_slist_sort(response_list, (GCompareFunc)db_sort_time);
    xmlDocPtr struct_resp = xmlParseDoc(BAD_CAST db_response);
@@ -677,7 +730,7 @@ xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
    gint messages_from = 0;
    gint messages_to = 0;
 
-   gchar* str;
+   gchar* str = NULL;
 
    /** get parametrs in Params node**/
    Obj = db_xpath(REQUEST_PARAMS_TAG_XPATH, ui_request);
@@ -691,34 +744,28 @@ xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
        } else {
              messages_from = 0;			
        }
-        
+       g_free(str);        
+       
        char * node_prop =  g_strdup_printf("%d", messages_from);
        xmlSetProp(node_root, BAD_CAST "From", BAD_CAST node_prop);
        free(node_prop);		
 
-	/** get TO **/ 
-	str = (gchar*)xmlGetProp(node_set,BAD_CAST "To");
-	if (str != NULL) {
-		messages_to = atoi(str);
-	} else {
-		messages_to = 10;			
-	} 
+	    /** get TO **/ 
+	    str = (gchar*)xmlGetProp(node_set,BAD_CAST "To");
+	    if (str != NULL) {
+		    messages_to = atoi(str);
+	    } else {
+		    messages_to = 10;			
+	    } 
+	
         char *message_to_prop = g_strdup_printf("%d", messages_to);
         xmlSetProp(node_root, BAD_CAST "To", BAD_CAST message_to_prop);
         g_free(message_to_prop);
    }
 
-	if (response_list == NULL ) {
-		db_resp = xmlParseDoc(BAD_CAST db_message); 
-		db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
-									  DB_GET_ERROR_INBOX_MESSAGE_TEXT, 
-									  DB_GET_ERROR_INBOX_MESSAGE_CODE);
-		return db_resp;		
-	}
-
 	GSList* list = g_slist_nth(response_list, messages_from);
 
-	for (i=messages_from; i<messages_to; i++) {
+    for (i = messages_from; i < messages_to; i++) {
 
             node_set = xmlDocGetRootElement((xmlDocPtr)list->data);
             xmlUnlinkNode(node_set);
@@ -729,18 +776,25 @@ xmlDocPtr DB_GET_INBOX_MESSAGES(xmlDocPtr ui_request)
             }
 
             xmlDocSetRootElement((xmlDocPtr)list->data, NULL);
-            xmlFreeDoc((xmlDocPtr)list->data);
 
             list = list->next;
 
-	}
+    }
+    
+    /* free memory in list elements */
+    while(response_list != NULL)
+    {
+	    xmlDocPtr cur_node = (xmlDocPtr)response_list->data;
+	    response_list = g_slist_remove(response_list, cur_node);
+	    xmlFreeDoc(cur_node);
+    }
 
-	db_resp = db_generate_response(struct_resp, node_root,
-								   CLASS_BOX_MESSAGE, GET_INBOX_MESSAGES);
+    db_resp = db_generate_response(struct_resp, node_root,
+				   CLASS_BOX_MESSAGE, cur_function);
+    
     xmlFreeDoc(ui_request);
     g_free(str);
-    xmlXPathFreeObject(Obj);
-	return db_resp;
+    return db_resp;
 }
 
 /**
@@ -780,7 +834,7 @@ xmlDocPtr GET_NEW_MESSAGES_FUNC(xmlDocPtr drv_response)
 		    db_resp = db_generate_message(db_resp, ERROR_MESSAGE, 
                                                    DB_GET_ERROR_INBOX_MESSAGES_TEXT, 
                                                    DB_GET_ERROR_INBOX_MESSAGES_CODE);
-		    return db_resp;		
+		    return db_resp;
 	    }
     }
 
@@ -797,8 +851,7 @@ xmlDocPtr GET_NEW_MESSAGES_FUNC(xmlDocPtr drv_response)
 
      xmlXPathFreeObject(Obj);
      xmlFreeDoc(drv_response);
-     return NULL;    
-       
+     return NULL;
 }
 
 /**
@@ -817,15 +870,17 @@ static xmlDocPtr db_generate_response(xmlDocPtr response, xmlNodePtr resp_params
 	xmlNodePtr node;
 	xmlXPathObject *Obj;
 
+    if (response == NULL) {
+        g_debug("response is null!");
+        return 0;
+    }
 
-	/** get request node and set class and function**/
-	Obj = db_xpath(RESPONSE_TAG_XPATH, response);
-	//xmlDocDump(stdout, response);	
-
-        if (Obj == NULL || response == NULL) {
-            g_debug("obj is null!");
-            return 0;
-        }
+	/** get request node and set class and function**/	
+    Obj = db_xpath(RESPONSE_TAG_XPATH, response);
+    if (Obj == NULL) {
+        g_debug("obj is null!");
+        return 0;
+    }
         
 	if (Obj->nodesetval->nodeNr != 0) {
 
@@ -836,15 +891,19 @@ static xmlDocPtr db_generate_response(xmlDocPtr response, xmlNodePtr resp_params
 		xmlSetProp(node, BAD_CAST "class", BAD_CAST class_name);	
 		xmlSetProp(node, BAD_CAST "function", BAD_CAST function_name);
 		
-		/** add response **/
+		/** add resp_params node with all information, in response struct **/
 		xmlAddChild(node, resp_params);
-                g_debug("1111");
-                g_debug("\nHruuuuuuuuuuuuu!\, %s ", xmlNodeGetContent(node));
-        }
 
-        xmlXPathFreeObject(Obj);
+//        xmlChar *content = xmlNodeGetContent(node);
+//        xmlFree(content);
+
+//        free(class_name);
+//        free(function_name);    
+    }
+
+    xmlXPathFreeObject(Obj);
 	g_debug("db_generate_response: END");
-        return response;
+    return response;
 }
 
 
@@ -873,27 +932,33 @@ static xmlDocPtr db_generate_message(xmlDocPtr response, char* function_name,
 		return NULL;	
 	}
 
+	xmlXPathFreeObject(Obj);
+
 	/** set text **/
 	char* xpath_req = g_strconcat(RESPONSE_TAG_XPATH,
 							 	  "/Params/string[@name='text']", NULL);
 
 	Obj = db_xpath(xpath_req, response);
+    g_free(xpath_req);
 	if (Obj->nodesetval->nodeNr != 0) {
 		node = Obj->nodesetval->nodeTab[0];
-		xmlNodeSetContent(node, BAD_CAST text);
+		xmlNodeSetContent(node, BAD_CAST (text));
 	} 
 
+	xmlXPathFreeObject(Obj);
+
 	/** set code **/
 	xpath_req = g_strconcat(RESPONSE_TAG_XPATH,
 							"/Params/string[@name='code']", NULL);
 
 	Obj = db_xpath(xpath_req, response);
+	g_free(xpath_req);
 	if (Obj->nodesetval->nodeNr != 0) {
 		node = Obj->nodesetval->nodeTab[0];
 		xmlNodeSetContent(node, BAD_CAST code);
 	}
-    
-    xmlXPathFreeObject(Obj);
+
+	xmlXPathFreeObject(Obj);
 
 	return response;
 
@@ -924,10 +989,11 @@ static char* db_get_request_id(char* class, db_type req_type, xmlDocPtr request)
 		}
 			
 		if (Obj->nodesetval->nodeNr != 0) {
-			node = Obj->nodesetval->nodeTab[0];			
-			g_debug("db_get_request_id: END %s", xmlGetProp(node, BAD_CAST "id"));
+			node = Obj->nodesetval->nodeTab[0];
+		    gchar *id = (char*) xmlGetProp(node, BAD_CAST "id");
+			g_debug("db_get_request_id: END %s", id);
             xmlXPathFreeObject(Obj);
-			return (char*)xmlGetProp(node, BAD_CAST "id");
+			return id;
 
 		}
 
@@ -989,7 +1055,7 @@ static gint db_sort_time(gpointer a, gpointer b)
 
     xmlXPathObject *Obj = db_xpath("//struct/date[@name='Time']", doc_a);
 
-    if (Obj->nodesetval->nodeNr > 0) {
+    if (Obj != NULL && Obj->nodesetval!= NULL && Obj->nodesetval->nodeNr > 0) {
             node_a = Obj->nodesetval->nodeTab[0];
     }
 
@@ -997,14 +1063,14 @@ static gint db_sort_time(gpointer a, gpointer b)
 
     Obj = db_xpath("//struct/date[@name='Time']", doc_b);
 
-    if (Obj->nodesetval->nodeNr > 0) {
+    if (Obj!= NULL && Obj->nodesetval != NULL && Obj->nodesetval->nodeNr > 0) {
             node_b = Obj->nodesetval->nodeTab[0];
     }
 
     xmlChar* cont_a = xmlNodeGetContent(node_a);
     xmlChar* cont_b = xmlNodeGetContent(node_b);
     
-    gint icont_count = strcmp((char*)cont_b, (char*)cont_a);
+    gint icont_count = g_strcmp0((gchar*)cont_b, (gchar*)cont_a);
 
     xmlFree(cont_a);
     xmlFree(cont_b);
