@@ -1110,6 +1110,11 @@ static gint create_path(const gchar* db_name)
     g_db_path = db_path;
     
     DB_P2DEBUG(3, "DB_LOGIC - create_path: DB name = %s; path = %s", g_db_name, g_db_path);
+
+// !!!
+    g_free(db_path);    
+    db_path = NULL;
+    g_db_path = NULL;
     
     return result;
 }
