@@ -53,11 +53,10 @@ gint create_owner_metacontact(xmlDocPtr doc) {
         
 	if (result) {
    		xmlNodeSetPtr nodeset = result->nodesetval;
-		
-//        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
 
 		if (nodeset->nodeNr == 2) {
-            if (xmlStrcmp(xmlGetProp(nodeset->nodeTab[0], BAD_CAST "name"), BAD_CAST "FirstName") == 0) {
+		    xmlChar* firstname = xmlGetProp(nodeset->nodeTab[0], BAD_CAST "name");
+            if (xmlStrcmp(firstname, BAD_CAST "FirstName") == 0) {
                 first_name = xmlNodeGetContent(nodeset->nodeTab[0]);
                 surname = xmlNodeGetContent(nodeset->nodeTab[1]);                		
                 	
@@ -65,6 +64,7 @@ gint create_owner_metacontact(xmlDocPtr doc) {
                 first_name = xmlNodeGetContent(nodeset->nodeTab[1]);
                 surname = xmlNodeGetContent(nodeset->nodeTab[0]);   		    
 		    }
+		    xmlFree(firstname);
 		}
    		xmlXPathFreeObject(result);
 	} 
@@ -104,6 +104,10 @@ gint create_owner_metacontact(xmlDocPtr doc) {
     
     
     g_free(xpath);      
+    xmlFree(first_name);
+    xmlFree(surname);
+    xmlFree(ns);
+    
     gchar** params = g_new(gchar*, 3);
                     
     params[0] = g_strdup("ID");
@@ -205,24 +209,17 @@ GSList* get_messages()
 
     if (result != NULL) {
 	    xmlNodeSetPtr nodeset = result->nodesetval;
-		
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
-		gint i;		
 
-        for(i = size; i >= 0; --i) {
+        for(gint i = nodeset->nodeNr - 1; i >= 0; --i) {
 		    xmlNodePtr node = xmlCopyNode(nodeset->nodeTab[i], 1);
 		    xmlBufferPtr buf = xmlBufferCreate();
 		    xmlNodeDump(buf, NULL, node, 0, 1);
 	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);
-        	        
 
-	        ////g_printf("\n\nNODE Content: %s", content);
-	        
 	        xmlDocPtr elem = xmlParseDoc(content);
 	        
             xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_MESSAGES, elem, NULL);
 	        
-   	        ////g_printf("\n\nNODE Afte transform1: ");
    	        load_binary_data_to_doc(SCHEMA_NAME_MESSAGES, external_format);
 
 	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));
@@ -257,25 +254,21 @@ GSList* get_owner_messages()
     if (result != NULL) {
 	    xmlNodeSetPtr nodeset = result->nodesetval;
 		
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
-		gint i;		
+        gint size = nodeset->nodeNr - 1;
 
-        for(i = size; i >= 0; --i) {
+        for(gint i = size; i >= 0; --i) {
 		    xmlNodePtr node = xmlCopyNode(nodeset->nodeTab[i], 1);
 		    xmlBufferPtr buf = xmlBufferCreate();
 		    xmlNodeDump(buf, NULL, node, 0, 1);
 	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);
 	        
-	        ////g_printf("\n\nNODE Content: %s", content);
-	        
 	        xmlDocPtr elem = xmlParseDoc(content);
 	        
             xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_OWNER_MESSAGES, elem, NULL);
 	        
-   	        ////g_printf("\n\nNODE Afte transform1: ");
    	        load_binary_data_to_doc(SCHEMA_NAME_OWNER_MESSAGES, external_format);
-   	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));  
-            xmlFreeDoc(external_format);
+   	        doc_list = g_slist_prepend(doc_list, external_format);  
+            //xmlFreeDoc(external_format);
    	        xmlFreeDoc(elem);    
    	        xmlFreeNode(node);
 	        //xmlFree(content);
@@ -306,31 +299,27 @@ GSList* get_contacts(gboolean with_owner) {
     if (result != NULL) {
         xmlNodeSetPtr nodeset = result->nodesetval;
 		
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
-        int i;
+        gint size = nodeset->nodeNr - 1;
 
-        for(i = size; i >= 0; --i) {
+        for(gint i = size; i >= 0; --i) {
                 xmlNodePtr node = xmlCopyNode(nodeset->nodeTab[i], 1);
                 xmlBufferPtr buf = xmlBufferCreate();
                 xmlNodeDump(buf, NULL, node, 0, 1);
 	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);
-	    
-	        ////g_printf("\n\nNODE Content: %s", content);
 	        
 	        xmlDocPtr elem = xmlParseDoc(content);
 
-                //xmlDocDump(stdout, elem);
-                xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS_LIST, elem, NULL);
-                xmlDocDump(stdout, external_format);
+            xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS_LIST, elem, NULL);
+                //xmlDocDump(stdout, external_format);
                 
    	       
    	        load_binary_data_to_doc(SCHEMA_NAME_CONTACTS_LIST, external_format);
-   	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));
-   	        xmlFreeDoc(external_format);
+   	        doc_list = g_slist_prepend(doc_list, external_format);
+   	        
    	        xmlFreeDoc(elem); 
    	        xmlFreeNode(node); 
 	        //xmlFree(content);
-                xmlBufferFree(buf); 
+            xmlBufferFree(buf); 
         }
         
         xmlXPathFreeObject(result);	      
@@ -357,25 +346,22 @@ GSList* get_profiles(gboolean with_owner) {
     if (result != NULL) {
 	    xmlNodeSetPtr nodeset = result->nodesetval;
 		
-        gint size = (nodeset) ? nodeset->nodeNr - 1 : 0;
-		gint i;		
+        gint size = nodeset->nodeNr - 1;	
 
-        for(i = size; i >= 0; --i) {
+        for(gint i = size; i >= 0; --i) {
 		    xmlNodePtr node = xmlCopyNode(nodeset->nodeTab[i], 1);
 		    xmlBufferPtr buf = xmlBufferCreate();
 		    xmlNodeDump(buf, NULL, node, 0, 1);
 	        xmlChar* content = (xmlChar*)xmlBufferContent(buf);
 	        
-	        ////g_printf("\n\nNODE Content: %s", content);
-	        
 	        xmlDocPtr elem = xmlParseDoc(content);
 
             xmlDocPtr external_format = db_apply_revers_stylesheet(SCHEMA_NAME_CONTACTS, elem, NULL);
 	        
    	        ////g_printf("\n\nNODE Afte transform1: ");
    	        load_binary_data_to_doc(SCHEMA_NAME_CONTACTS, external_format);
-   	        doc_list = g_slist_prepend(doc_list, xmlCopyDoc(external_format,1));
-   	        xmlFreeDoc(external_format);
+   	        doc_list = g_slist_prepend(doc_list, external_format);
+   	        //xmlFreeDoc(external_format);
    	        xmlFreeDoc(elem);    
    	        xmlFreeNode(node);
 	        //xmlFree(content);
@@ -392,15 +378,18 @@ GSList* get_profiles(gboolean with_owner) {
 gint create_or_update_contact(xmlDocPtr contact, gchar* outer_id)
 {
 
+    gchar *id = g_strconcat("\"", outer_id, "\"", NULL);
+    db_remove_node_by_id(SCHEMA_NAME_CONTACTS_LIST, id);
     
-    db_remove_node_by_id(SCHEMA_NAME_CONTACTS_LIST, g_strconcat("\"", outer_id, "\"", NULL));
     gchar** params = g_new(gchar*, 3);    
     params[0] = g_strdup("ID");
-    params[1] = g_strconcat("\"", outer_id, "\"", NULL);
+    params[1] = g_strdup(id);
     params[2] = NULL;       
 
     db_add_data_to_db_with_id(SCHEMA_NAME_CONTACTS_LIST, contact, (const gchar**)params);
+    g_free(id);
     g_strfreev(params);            
+    
     return 0;
 }
 
@@ -408,169 +397,60 @@ gint create_or_update_contact(xmlDocPtr contact, gchar* outer_id)
 gint create_or_update_profile(xmlDocPtr contact, gchar* outer_id)
 {
 
+    gchar* id = g_strconcat("\"", outer_id, "\"", NULL);
+    db_remove_node_by_id(SCHEMA_NAME_CONTACTS, id);
     
-    db_remove_node_by_id(SCHEMA_NAME_CONTACTS, g_strconcat("\"", outer_id, "\"", NULL));
     gchar** params = g_new(gchar*, 3);    
     params[0] = g_strdup("ID");
-    params[1] = g_strconcat("\"", outer_id, "\"", NULL);
+    params[1] = g_strdup(id);
     params[2] = NULL;       
 
     db_add_data_to_db_with_id(SCHEMA_NAME_CONTACTS, contact, (const gchar**)params);
+    g_free(id);
     g_strfreev(params);            
+    
     return 0;
 }
 
 
 gint create_or_update_message(xmlDocPtr message, gchar* outer_id)
 {
-    db_remove_node_by_id(SCHEMA_NAME_MESSAGES, g_strconcat("\"", outer_id, "\"", NULL));
+    gchar *id = g_strconcat("\"", outer_id, "\"", NULL);
+    db_remove_node_by_id(SCHEMA_NAME_MESSAGES, id);
+
     gchar** params = g_new(gchar*, 3);    
     params[0] = g_strdup("ID");
-    params[1] = g_strconcat("\"", outer_id, "\"", NULL);
+    params[1] = g_strdup(id);
     params[2] = NULL;       
 
     db_add_data_to_db_with_id(SCHEMA_NAME_MESSAGES, message, (const gchar**)params);
+    
+    g_free(id);
     g_strfreev(params);            
     return 0;
 }
 
 gint create_or_update_owner_message(xmlDocPtr message, gchar* outer_id)
 {
-    db_remove_node_by_id(SCHEMA_NAME_OWNER_MESSAGES, g_strconcat("\"", outer_id, "\"", NULL));
+    gchar *id = g_strconcat("\"", outer_id, "\"", NULL);
+
+    db_remove_node_by_id(SCHEMA_NAME_OWNER_MESSAGES, id);
+    
     gchar** params = g_new(gchar*, 3);    
     params[0] = g_strdup("ID");
-    params[1] = g_strconcat("\"", outer_id, "\"", NULL);
+    params[1] = g_strdup(id);
     params[2] = NULL;       
 
     db_add_data_to_db_with_id(SCHEMA_NAME_OWNER_MESSAGES, message, (const gchar**)params);
+    
+    g_free(id);
     g_strfreev(params);            
-    return 0;
-}
-
-
-gint create_or_update_contact1(xmlDocPtr contact, gchar* outer_id)
-{
-
-
-    if (contact == NULL || outer_id == NULL) {
-        return FAILURE;
-    }   
-
-    gchar* xpath_req = g_strconcat(DB_XPATH_KNOWNAS_ID_REQ, "='", outer_id, "']", NULL );
-    xmlDocPtr metacontacts_table = get_table_from_list(METACONTACTS_SCHEMA_NAME);
-    xmlChar* ns = BAD_CAST cm_get_namespaces_key(METACONTACTS_SCHEMA_NAME);
-
-    g_debug("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! %s", xpath_req);
-
-    if (db_get_nodes_count(metacontacts_table, BAD_CAST xpath_req, ns) == 0) {
-        g_debug("CREATE");
-        gchar* new_id = db_add_data_to_db(METACONTACTS_SCHEMA_NAME, contact, NULL);
-        
-        g_free(xpath_req);
-        xpath_req = g_strconcat(DB_XPATH_PERSON_REQ, "[@", ID_PREFIX, ":", ID_NAME, "='", new_id, "']", NULL);
-        
-//        GSList* list = db_get_node_by_id(METACONTACTS_SCHEMA_NAME, new_id);
-       
-        xmlXPathObjectPtr result = db_get_nodeset(metacontacts_table, BAD_CAST xpath_req, ns);
-        
-        if (result) {
-	        gint count = result->nodesetval->nodeNr;    
-   		    if (count > 0) {
-   		        xmlNodePtr node = (xmlNodePtr)result->nodesetval->nodeTab[0];
-   		        xmlNodePtr new_link = create_link_node(outer_id);
-   		        xmlAddChild(node, new_link);
-
-     gchar* db_path = cm_get_db_path_by_name_or_default(NULL);
-     db_save_table(metacontacts_table, METACONTACTS_SCHEMA_NAME, db_path);
-     g_free(db_path);
-            gchar** params = g_new(gchar*, 3);    
-            params[0] = g_strdup("ID");
-            params[1] = g_strdup(outer_id);
-            params[2] = NULL;       
-            db_add_data_to_db_with_id(SCHEMA_NAME_CONTACTS_LIST, contact, (const gchar**)params);
-            g_strfreev(params);
-   		    }
-   		    xmlXPathFreeObject(result);
-	    } 
-
-    } else {
-         db_remove_node_by_id(SCHEMA_NAME_CONTACTS_LIST, outer_id);
-        gchar** params = g_new(gchar*, 3);    
-            params[0] = g_strdup("ID");
-            params[1] = g_strdup(outer_id);
-            params[2] = NULL;       
-        
-            db_add_data_to_db_with_id(SCHEMA_NAME_CONTACTS_LIST, contact, (const gchar**)params);
-            g_strfreev(params);            
-    }
-
-
     
-    g_free(xpath_req);
-    xmlFree(ns);
     return 0;
 }
 
 
 
-gint create_or_update_profile1(xmlDocPtr contact, gchar* outer_id)
-{
-    if (contact == NULL || outer_id == NULL) {
-        return FAILURE;
-    }   
-
-    gchar* xpath_req = g_strconcat(DB_XPATH_KNOWNAS_ID_REQ, "='", outer_id, "']", NULL );
-    xmlDocPtr metacontacts_table = get_table_from_list(METACONTACTS_SCHEMA_NAME);
-    xmlChar* ns = BAD_CAST cm_get_namespaces_key(METACONTACTS_SCHEMA_NAME);
- 
-
-    if (db_get_nodes_count(metacontacts_table, BAD_CAST xpath_req, ns) == 0) {
-        g_debug("CREATE");
-        gchar* new_id = db_add_data_to_db(METACONTACTS_SCHEMA_NAME, contact, NULL);
-        
-        g_free(xpath_req);
-        xpath_req = g_strconcat(DB_XPATH_PERSON_REQ, "[@", ID_PREFIX, ":", ID_NAME, "='", new_id, "']", NULL);
-      
-        xmlXPathObjectPtr result = db_get_nodeset(metacontacts_table, BAD_CAST xpath_req, ns);
-        
-        if (result) {
-	        gint count = result->nodesetval->nodeNr;    
-   		    if (count > 0) {
-   		        xmlNodePtr node = (xmlNodePtr)result->nodesetval->nodeTab[0];
-   		        xmlNodePtr new_link = create_link_node(outer_id);
-   		        xmlAddChild(node, new_link);
-
-             gchar* db_path = cm_get_db_path_by_name_or_default(NULL);
-             db_save_table(metacontacts_table, METACONTACTS_SCHEMA_NAME, db_path);
-            g_free(db_path);
-            gchar** params = g_new(gchar*, 3);    
-            params[0] = g_strdup("ID");
-            params[1] = g_strdup(outer_id);
-            params[2] = NULL;       
-            db_add_data_to_db_with_id(SCHEMA_NAME_CONTACTS, contact, (const gchar**)params);
-            g_strfreev(params);
-   		    }
-   		    xmlXPathFreeObject(result);
-	    } 
-
-    } else {
-         db_remove_node_by_id(SCHEMA_NAME_CONTACTS, outer_id);
-        gchar** params = g_new(gchar*, 3);    
-            params[0] = g_strdup("ID");
-            params[1] = g_strdup(outer_id);
-            params[2] = NULL;       
-        
-            db_add_data_to_db_with_id(SCHEMA_NAME_CONTACTS, contact, (const gchar**)params);
-            g_strfreev(params);
-    }
-
-
-    
-    g_free(xpath_req);
-    xmlFree(ns);
-    return 0;
-}
-
 
 GSList* db_get_profile(gchar* id)
 {
