@@ -43,7 +43,8 @@ const char* img_resp = "\
 extern int msa_module_init(msa_module *module)
 {
     g_print("driver %s: init!", UI_NAME);   
-    module->name = g_strndup(UI_NAME, 9);
+// !!!     
+    module->name = UI_NAME;//g_strndup(UI_NAME, 9);
     module->send = ui_got_response;
     module->module_start = ui_start;
     module->status = 1;
@@ -90,7 +91,7 @@ int ui_got_response(xmlDocPtr response, xmlDocPtr* answer, msa_module* ui_info_n
         gchar* class_name = NULL;
         gchar* func = NULL;
         GSource* source = g_timeout_source_new(TIMEOUT);
-        hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
+        //hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
         
         if (get_function_from_response(response, &class_name, &func) == 0 ) {
             g_print("UI GOT RESPONSE: %s -> %s", class_name, func);
@@ -171,6 +172,10 @@ gboolean ui_driver_get_profile(gpointer request)
 	    } else return FALSE;
     } else return FALSE;
 
+// !!!
+  	xmlXPathFreeObject(obj);	
+  	obj = NULL;
+
     GList* children = gtk_container_get_children (GTK_CONTAINER(ui_data->box_profile));
     for (; children != NULL; children = children->next){
         gtk_widget_destroy(children->data); 
@@ -190,7 +195,11 @@ gboolean ui_driver_get_profile(gpointer request)
     {
         gchar* type = (gchar*)node->name;
         if (!strcmp(type, TYPE_STRNG)) {
-            label = ui_init_label(xmlGetProp(node, "name"));
+// !!!
+            gchar* prop_val = xmlGetProp(node, "name");
+            label = ui_init_label(prop_val);
+            g_free(prop_val);
+            
             detail = hildon_entry_new(HILDON_SIZE_FINGER_HEIGHT);
             gtk_entry_set_text(GTK_ENTRY(detail), (gchar*)xmlNodeGetContent(node));
             gtk_box_pack_start(GTK_BOX(vbox_left), label, TRUE, TRUE, 0);        
@@ -198,7 +207,10 @@ gboolean ui_driver_get_profile(gpointer request)
         } else if (!strcmp(type, TYPE_IMAGE)) {
             cont = node;
         } else if (!strcmp(type, TYPE_SELCT)) {
-            label = ui_init_label(xmlGetProp(node, "name"));
+            gchar* prop_val = xmlGetProp(node, "name");
+            label = ui_init_label(prop_val);
+            g_free(prop_val);
+            
             GtkWidget *selector = hildon_touch_selector_new_text ();
             detail = hildon_picker_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
             hildon_picker_button_set_selector(detail, selector);
@@ -220,7 +232,11 @@ gboolean ui_driver_get_profile(gpointer request)
             }
             hildon_touch_selector_set_active(selector, 0, n);
             //hildon_picker_button_set_done_button_text(detail, str_value);
-            gtk_widget_set_name(GTK_WIDGET(selector), xmlGetProp(node, "name"));
+// !!!
+            prop_val = xmlGetProp(node, "name");
+            gtk_widget_set_name(GTK_WIDGET(selector), prop_val);
+            g_free(prop_val);      
+            
             hildon_button_set_value_alignment(detail, 0, 0.5);
             hildon_button_set_title_alignment(detail, 0, 0.5);
             g_signal_connect(G_OBJECT(detail), "value-changed", G_CALLBACK(callback_combo_changed), (gpointer)xmlGetProp(node, "name"));
@@ -228,8 +244,12 @@ gboolean ui_driver_get_profile(gpointer request)
             gtk_box_pack_start(GTK_BOX(vbox_edit), detail, FALSE, FALSE, 0);
             gtk_button_set_relief(GTK_WIDGET(detail), GTK_RELIEF_NONE);
         } else if (!strcmp(type, TYPE_DATE)) {
-            label = ui_init_label(xmlGetProp(node, "name"));
-            detail = ui_init_date_chooser(xmlGetProp(node, "name"), (gchar*)xmlNodeGetContent(node));
+            gchar* prop_val = (gchar*) xmlGetProp(node, "name");
+            label = ui_init_label(prop_val);
+            g_free(prop_val);
+            
+// !!            detail = ui_init_date_chooser(xmlGetProp(node, "name"), (gchar*)xmlNodeGetContent(node));
+            detail = ui_init_date_chooser(NULL, (gchar*)xmlNodeGetContent(node));
             gtk_button_set_relief(GTK_WIDGET(detail), GTK_RELIEF_NONE);
             hildon_button_set_value_alignment(detail, 0, 0.5);
             hildon_button_set_title_alignment(detail, 0, 0.5);
@@ -279,7 +299,11 @@ gboolean ui_driver_get_profile(gpointer request)
 static gpointer ui_init_label(gchar* str_label)
 {
     GtkWidget* label = gtk_label_new(NULL);
-    gtk_label_set_markup(GTK_LABEL(label),(g_strconcat(MARKUP,str_label,": ",PUKRAM,NULL)));    
+// !!!
+    gchar* label_text = g_strconcat(MARKUP,str_label,": ",PUKRAM,NULL);
+    gtk_label_set_markup(GTK_LABEL(label),label_text);    
+    g_free(label_text);
+    
     GtkWidget* alignment_label = gtk_alignment_new(1, 0.5, 0, 0);
     gtk_container_add(GTK_CONTAINER(alignment_label), label);
     gtk_widget_show_all(alignment_label);
@@ -312,6 +336,7 @@ static gpointer ui_init_date_chooser(gchar* str_label, gchar* str_value)
     gint y = atoi(numbers[2]);
     gint m = atoi(numbers[1]) - 1;
     gint d = atoi(numbers[0]);
+    g_strfreev(numbers);
     GtkWidget* button = hildon_date_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
     hildon_date_button_set_date (button, y, m, d);
     hildon_button_set_title(button, NULL);
@@ -345,7 +370,11 @@ gboolean ui_driver_get_friends(gpointer request)
     node = Obj->nodesetval->nodeTab[0];
     g_hash_table_foreach_remove(ui_data->table_imgs, remove_friends_img, NULL);
     node_root = node->children;
-    ui_data->num_frds = atoi(xmlGetProp(node,"friendsQuantity"));
+
+    xmlChar* prop_value = xmlGetProp(node,"friendsQuantity");
+    ui_data->num_frds = atoi((const char*)prop_value);
+    xmlFree(prop_value);
+    
     str_filter = xmlGetProp(node, "Filter");
     if (str_filter != NULL) {
         if (strlen(str_filter) > 0) {
@@ -465,7 +494,7 @@ gpointer ui_friend(gpointer ptr_friend)
         xmlSetProp(node_img, "uri", friend->str_uri);
         xmlAddChild(node_params, node_img);
         kernel->send(img_req, NULL, NULL);
-        hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
+        //hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
     }
     
     gtk_widget_set_usize(GTK_WIDGET(button_msg), MIN_WIDTH_CONTROL, NULL);
@@ -618,9 +647,22 @@ gboolean ui_driver_get_messages(gpointer request)
     
     Obj = xpath(RESPONSE_PARAMS_TAG_XPATH, request);
     node = Obj->nodesetval->nodeTab[0];
-    ui_data->num_msgs = atoi(xmlGetProp(node, "messagesQuantity"));
-    from = atoi(xmlGetProp(node, "From"));
-    to = atoi(xmlGetProp(node, "To"));
+
+    char* prop_val = (char*)xmlGetProp(node, "messagesQuantity");
+    ui_data->num_msgs = atoi(prop_val);
+    free(prop_val);
+    
+    prop_val = xmlGetProp(node, "From");
+    from = atoi(prop_val);
+    free(prop_val);
+    
+    
+    prop_val = xmlGetProp(node, "To");
+    to = atoi(prop_val);
+    free(prop_val);
+    
+    prop_val = NULL;
+    
     if (to > ui_data->num_msgs) {
 		to = ui_data->num_msgs;
     }
@@ -735,6 +777,8 @@ gpointer ui_message(gpointer msg_pointer)
     strftime(str_date, 11, "%d.%m.%Y\0", tm_time);
     strftime(str_time, 7, "%H:%M\0", tm_time);
     msg->str_date = str_date;
+// !!!    
+    g_free(msg->str_time);    
     msg->str_time = str_time;
     gtk_label_set_markup(GTK_LABEL(label_time), g_strconcat(MARKUP, " ", str_date, "  ", str_time, PUKRAM, NULL));
     GtkWidget* label_text = gtk_label_new(NULL);
@@ -1004,7 +1048,7 @@ gboolean ui_show_info(gpointer request)
     } else {
         hildon_banner_show_information(ui_data->window, NULL, DB_SAVE_MESSAGE_FRIENDS_PROFILE_TEXT);
     }
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
+    //hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
     g_free(code);
     xmlFreeDoc(request);
     return FALSE;    
@@ -1019,7 +1063,7 @@ gboolean ui_show_error(gpointer request)
 {
     g_source_destroy(ui_data->source_time);
     g_source_unref(ui_data->source_time);
-    
+    gboolean show = TRUE;
     gchar* text;
     gchar* code;
 
@@ -1039,20 +1083,28 @@ gboolean ui_show_error(gpointer request)
     g_print("\n##################\n#                #\n#   ERROR: %s   #\n#                #\n##################\n", code);
     
     if(strcmp(code, DB_GET_ERROR_FRIENDS_CODE) == 0) {
+        show = FALSE;
         gtk_label_set_text(GTK_LABEL(ui_data->label_friends_page), STR_EMPT);
         callback_button_friends_update(NULL, NULL);
     }
     if(strcmp(code, DB_GET_ERROR_PROFILE_CODE) == 0){
+        show = FALSE;
         callback_button_profile_update(NULL, NULL);
     }
     if(strcmp(code, DB_GET_ERROR_INBOX_MESSAGES_CODE) == 0 || strcmp(code, DB_GET_ERROR_OUTBOX_MESSAGES_CODE) == 0){
+        show = FALSE;
         callback_button_messages_update(NULL, NULL);
     }
     if(strcmp(code, DB_SAVE_ERROR_FRIENDS_PROFILE_CODE) == 0){
+        show = FALSE;
         g_signal_emit_by_name(ui_data->button_friend_profile_refresh, "clicked");
     }
-    hildon_banner_show_information(ui_data->window, NULL, text);
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
+    if(strcmp(code, DB_GET_ERROR_BINARY_CODE) == 0){
+        show = FALSE;
+    }
+    if(show)
+        hildon_banner_show_information(ui_data->window, NULL, text);
+    //hildon_gtk_window_set_progress_indicator (ui_data->window, 0);
     xmlXPathFreeObject(obj);
     xmlFreeDoc(request);
 
