@@ -52,11 +52,10 @@ void callback_full(GtkAction* action, gpointer data)
 **/
 void callback_goto(GtkWidget* widget, int i)
 {
-    gtk_window_set_title (GTK_WINDOW (ui_data->window), ui_data->str_page[i]);
+    gtk_window_set_title(GTK_WINDOW (ui_data->window), ui_data->str_page[i]);
     gtk_notebook_set_current_page(GTK_NOTEBOOK(ui_data->tasks), i);
     ui_data->prev = ui_data->page;
     ui_data->page = i;
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
     if (ui_data->page == 2 && !ui_data->empty_profile) {
         ui_data->empty_profile = FALSE;
         callback_button_profile_update(NULL, NULL);
@@ -221,15 +220,13 @@ void callback_date_changed(GtkWidget* widget, gpointer user_data)
 **/
 void callback_button_profile_get(GtkWidget* button, gpointer data)
 {
-    //g_print("putting data in kernel\n");
     xmlDocPtr resp = NULL;
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc("<?xml version=\"1.0\"?><TransitData id=\"1\" \
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"profile\" function = \"getProfile\"><Params></Params></Request></Content></TransitData>"), &resp, NULL);
     xmlFreeDoc(resp);
-    //g_print("data was put in kernel\n");
-    hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
 }
 
 /**
@@ -239,7 +236,7 @@ void callback_button_profile_get(GtkWidget* button, gpointer data)
 **/
 void callback_button_friends_get(GtkWidget* button, gpointer data)
 {
-    hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     int from = FRIENDS_PER_PAGE*ui_data->page_frds;
     int to = FRIENDS_PER_PAGE*(ui_data->page_frds + 1);
     gchar* str_sort;
@@ -328,15 +325,13 @@ void callback_button_friends_result(GtkWidget* button_cb, gpointer data)
 **/
 void callback_button_friends_update(GtkWidget* button, gpointer data)
 {
-    //g_print("!!!\t CALLBACK FRIENDS UPDATE\t !!!\n");
     xmlDocPtr resp = NULL;
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc("<?xml version=\"1.0\"?><TransitData id=\"1\" \
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"friends\" function = \"updateListFriends\"><Params></Params></Request></Content></TransitData>"), &resp, NULL);
     xmlFreeDoc(resp);
-    //g_print("data was put in kernel\n");
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
 }
 
 /**
@@ -433,15 +428,13 @@ void callback_button_messages_get(GtkWidget* button, gpointer data)
     <TargetID>db</TargetID>\
     <Content><Request class=\"messages\" function = \"get",str_msgs_box,"Messages\"><Params From=\"",sfrom,
     "\" To=\"",sto,"\"></Params></Request></Content></TransitData>",NULL);
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
 
     g_free(request);
     g_free(str_msgs_box);
     g_free(sfrom);
     g_free(sto);
-
-    //g_print("data was put in kernel\n");
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
 }
 
 /**
@@ -496,10 +489,10 @@ void callback_message_send_reply(GtkWidget* button, gpointer data)
     gchar *request = g_strconcat("<?xml version=\"1.0\"?><TransitData id=\"1\" \
         type=\"data\"><SourceID>ui</SourceID><TargetID>vkontakte</TargetID><Content><Request class=\"messages\" function = \"sendMessage\">\
         <Params id=\"", gtk_widget_get_name(GTK_WIDGET(data)), "\"><string name=\"text\">", str_to_send , "</string></Params></Request></Content></TransitData>", NULL);
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
     g_free(str_to_send);
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
 }
 
 /**
@@ -578,11 +571,10 @@ void callback_friend(GtkWidget* container, gpointer value)
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"profile\" function = \"getProfile\"><Params id=\"", (gchar*)value, "\"></Params></Request></Content></TransitData>", NULL);
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
-
     ui_init_friend_profile(container, value);
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
 }
 
 /**
@@ -603,10 +595,10 @@ void callback_button_messages_update(GtkWidget* button, gpointer data)
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"messages\" function = \"update", str_msgs_box, "Messages\"><Params></Params></Request></Content></TransitData>", NULL);
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
     g_free(str_msgs_box);
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
 }
 
 /**
@@ -680,10 +672,10 @@ void callback_message_reply_entry(GtkWidget* button_cb, gpointer ptr_msg)
         gchar *request = g_strconcat("<?xml version=\"1.0\"?><TransitData id=\"1\" \
         type=\"data\"><SourceID>ui</SourceID><TargetID>vkontakte</TargetID><Content><Request class=\"messages\" function = \"sendMessage\">\
         <Params id=\"", msg->str_sender_id, "\"><string name=\"text\">", str_to_send , "</string></Params></Request></Content></TransitData>", NULL);
+        //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
         kernel->send(xmlParseDoc(request), NULL, NULL);
         g_free(request);
         g_free(str_to_send);
-        hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
     }
     
     gtk_widget_destroy(GTK_WIDGET(dialog));
@@ -711,9 +703,9 @@ void callback_button_friends_profile_update(GtkWidget* button, gpointer data)
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"profile\" function = \"updateProfile\"><Params id=\"",(gchar*)data,"\"></Params></Request></Content></TransitData>",NULL);
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
-    hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
 }
 
 /**
@@ -874,10 +866,9 @@ void callback_button_friends_find(GtkWidget* button_cb, gpointer data)
         type=\"data\"><SourceID>ui</SourceID>\
         <TargetID>db</TargetID>\
         <Content><Request class=\"friends\" function = \"getListFriends\"><Params Filter=\"",str,"\"/></Request></Content></TransitData>", NULL);
+        //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
         kernel->send(xmlParseDoc(request), NULL, NULL);
         g_free(request);
-        //g_free(str);
-        hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     }    
     gtk_widget_destroy(GTK_WIDGET(dialog));
 }
@@ -936,11 +927,11 @@ void callback_friend_send_message(GtkWidget* button_cb, gpointer ptr_str_id)
         gchar *request = g_strconcat("<?xml version=\"1.0\"?><TransitData id=\"1\" \
         type=\"data\"><SourceID>ui</SourceID><TargetID>vkontakte</TargetID><Content><Request class=\"messages\" function = \"sendMessage\">\
         <Params id=\"",(gchar*)ptr_str_id, "\"><string name=\"text\">", str_to_send , "</string></Params></Request></Content></TransitData>", NULL);
+        //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
         kernel->send(xmlParseDoc(request), NULL, NULL);
         g_free(request);
         g_free(str_to_send);
         g_free(str_msg);
-        hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
     }
     gtk_widget_destroy(GTK_WIDGET(dialog));
 }
@@ -974,9 +965,9 @@ void callback_button_friend_get(GtkWidget* button, gpointer data)
         type=\"data\"><SourceID>ui</SourceID>\
         <TargetID>db</TargetID>\
         <Content><Request class=\"profile\" function = \"getProfile\"><Params id=\"", (gchar*)data, "\"></Params></Request></Content></TransitData>", NULL);
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc(request), NULL, NULL);
     g_free(request);
-    hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
 }
 
 /**
@@ -987,12 +978,11 @@ void callback_button_friend_get(GtkWidget* button, gpointer data)
 **/
 void callback_button_profile_update(GtkWidget* button, gpointer data)
 {
+    //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
     kernel->send(xmlParseDoc("<?xml version=\"1.0\"?><TransitData id=\"1\" \
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>db</TargetID>\
     <Content><Request class=\"profile\" function = \"updateProfile\"><Params></Params></Request></Content></TransitData>"), NULL, NULL);
-    hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
-    //g_print("data was put in kernel\n");
 }
 
 /**
@@ -1017,6 +1007,9 @@ void callback_button_profile_save(GtkWidget* button, gpointer data)
     else {
         g_debug("callback_button_profile_save: save_request error response obj is null");    
     }
+// !!!    
+   	xmlXPathFreeObject(obj);	
+    obj = NULL;
     
     /** change source id **/
     obj = xpath(SOURCE_TAG_XPATH, req_drv);
@@ -1028,6 +1021,11 @@ void callback_button_profile_save(GtkWidget* button, gpointer data)
         g_debug("callback_button_profile_save: save_request error source obj is null");    
     }
     
+// !!!    
+   	xmlXPathFreeObject(obj);	
+    obj = NULL;
+    
+    
     /** create target id **/
     obj = xpath(TARGET_TAG_XPATH, req_drv);
     if (obj->nodesetval->nodeNr != 0) {
@@ -1041,6 +1039,12 @@ void callback_button_profile_save(GtkWidget* button, gpointer data)
         xmlNodePtr root = xmlDocGetRootElement(req_drv);
         xmlAddChild(root, node);    
     }
+    
+// !!!    
+   	xmlXPathFreeObject(obj);	
+    obj = NULL;
+
+    
     kernel->send(req_drv, NULL, NULL);
     if (ui_data->ui_request != NULL) {
         xmlFreeDoc(ui_data->ui_request);
@@ -1092,10 +1096,9 @@ void callback_button_setup_service(GtkWidget* button, gpointer id_service)
     type=\"data\"><SourceID>ui</SourceID>\
     <TargetID>",info->id,"</TargetID>\
     <Content><Request class=\"settings\" function = \"getSettings\"><Params></Params></Request></Content></TransitData>", NULL);
+            //hildon_gtk_window_set_progress_indicator(ui_data->window, 1);
             kernel->send(xmlParseDoc(request), NULL, NULL);
             g_free(request);
-            hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
-            g_print("\n\n!!!!!!!!!!! sending request to %s\n\n", info->id);
             break;
         }
         i++;
@@ -1184,9 +1187,9 @@ void callback_button_save_setup_service(GtkWidget* button, gpointer id)
             char* actv;
             actv = g_strdup("1");
             info->status = ON;
-            info->state = CONF;    
+            info->state = CONF;
+            //hildon_gtk_window_set_progress_indicator(ui_data->window, 1); 
             kernel->msa_settings(info->id, xmlParseDoc(g_strconcat("<?xml version=\"1.0\"?><TransitData><SourceID>ui</SourceID><TargetID>",info->id,"</TargetID><Content><Request class=\"settings\" function=\"setSettings\"><Params><string name=\"login\">",gtk_entry_get_text(GTK_LABEL(ui_data->entry_logn)),"</string><string name=\"password\">",gtk_entry_get_text(GTK_LABEL(ui_data->entry_pass)),"</string><number name=\"autoupdate\">",g_strdup_printf("%d",(hildon_number_editor_get_value(ui_data->entry_auto))),"</number><boolean name=\"active\">",actv,"</boolean></Params></Request></Content></TransitData>",NULL)));
-            hildon_gtk_window_set_progress_indicator (ui_data->window, 1);
             break;
         }
         i++;
@@ -1265,4 +1268,4 @@ void callback_exit(GtkAction* action, gpointer data)
 {
     kernel->shutdown();
     gtk_main_quit();
-}
+}
\ No newline at end of file
