@@ -332,34 +332,22 @@ static void ui_init_menu()
 {
     HildonAppMenu* main_menu = HILDON_APP_MENU(hildon_app_menu_new());
     /* menu items */
-    GtkWidget* menu_sets = GTK_WIDGET(hildon_button_new(HILDON_SIZE_AUTO, NULL));   
     GtkWidget* menu_help = GTK_WIDGET(hildon_button_new(HILDON_SIZE_AUTO, NULL));
     GtkWidget* menu_bout = GTK_WIDGET(hildon_button_new(HILDON_SIZE_AUTO, NULL));
     GtkWidget* menu_exit = GTK_WIDGET(hildon_button_new(HILDON_SIZE_AUTO, NULL));
     GtkWidget* menu_full = GTK_WIDGET(hildon_button_new(HILDON_SIZE_AUTO, NULL));
-    //ui_data->menu_full = GTK_WIDGET(hildon_gtk_toggle_button_new(HILDON_SIZE_AUTO));
-    //ui_data->menu_tool = GTK_WIDGET(hildon_gtk_toggle_button_new(HILDON_SIZE_AUTO));
-    /* set titles */
-    //gtk_button_set_label(GTK_BUTTON(ui_data->menu_full), STR_FULL);
-    //gtk_button_set_label(GTK_BUTTON(ui_data->menu_tool), STR_TOOL);
+    /* items' titles */
     hildon_button_set_title(GTK_BUTTON(menu_help), STR_HELP);
     hildon_button_set_title(GTK_BUTTON(menu_full), STR_FULL);
     hildon_button_set_title(GTK_BUTTON(menu_bout), STR_BOUT);
     hildon_button_set_title(GTK_BUTTON(menu_exit), STR_EXIT);
-    hildon_button_set_title(GTK_BUTTON(menu_sets), STR_SETS);
     /* append items */
-    hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(menu_sets));
     hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(menu_full));
-    //hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(ui_data->menu_full));
-    //hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(ui_data->menu_tool));
     hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(menu_bout));
     hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(menu_help));
     hildon_app_menu_append(HILDON_APP_MENU(main_menu), GTK_BUTTON(menu_exit));
     /* callback functions */
-    g_signal_connect_after(G_OBJECT(menu_sets), "clicked", G_CALLBACK(callback_sets), NULL);
     g_signal_connect_after(G_OBJECT(menu_full), "clicked", G_CALLBACK(callback_full), NULL);
-    //g_signal_connect_after(G_OBJECT(ui_data->menu_full), "clicked", G_CALLBACK(callback_full), NULL);
-    //g_signal_connect_after(G_OBJECT(ui_data->menu_tool), "clicked", G_CALLBACK(callback_tool), NULL);
     g_signal_connect_after(G_OBJECT(menu_help), "clicked", G_CALLBACK(callback_help), NULL);
     g_signal_connect_after(G_OBJECT(menu_bout), "clicked", G_CALLBACK(callback_bout), NULL);
     g_signal_connect_after(G_OBJECT(menu_exit), "clicked", G_CALLBACK(callback_exit), NULL);
